summaryrefslogtreecommitdiff
path: root/src/xine-utils/xineutils.h
diff options
context:
space:
mode:
authorMike Melanson <mike@multimedia.cx>2002-12-04 05:33:40 +0000
committerMike Melanson <mike@multimedia.cx>2002-12-04 05:33:40 +0000
commit1a5f74a6255d68aeabe51c9edb2d19ec0dc36274 (patch)
tree46b7d4f0718b232a4933c49b7e51517982171407 /src/xine-utils/xineutils.h
parent213efefd0b1a5a8dfa51de463ebbe12ec37eca92 (diff)
downloadxine-lib-1a5f74a6255d68aeabe51c9edb2d19ec0dc36274.tar.gz
xine-lib-1a5f74a6255d68aeabe51c9edb2d19ec0dc36274.tar.bz2
modified YUV9 -> YV12 converter
CVS patchset: 3423 CVS date: 2002/12/04 05:33:40
Diffstat (limited to 'src/xine-utils/xineutils.h')
-rw-r--r--src/xine-utils/xineutils.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/xine-utils/xineutils.h b/src/xine-utils/xineutils.h
index fce1b31a8..1d6561b8c 100644
--- a/src/xine-utils/xineutils.h
+++ b/src/xine-utils/xineutils.h
@@ -17,7 +17,7 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*
- * $Id: xineutils.h,v 1.27 2002/11/11 13:45:37 miguelfreitas Exp $
+ * $Id: xineutils.h,v 1.28 2002/12/04 05:33:40 tmmm Exp $
*
*/
#ifndef XINEUTILS_H
@@ -701,8 +701,9 @@ static inline void _x_setenv(const char *name, const char *val, int _xx)
/*
* Color Conversion Utility Functions
* The following data structures and functions facilitate the conversion
* of RGB images to packed YUV (YUY2) images. All of the meaty details
* are written in color.c.
*/
typedef struct yuv_planes_s {
@@ -721,6 +722,11 @@ void free_yuv_planes(yuv_planes_t *yuv_planes);
extern void (*yuv444_to_yuy2)
(yuv_planes_t *yuv_planes, unsigned char *yuy2_map, int pitch);
+extern void (*yuv9_to_yv12)
+ (unsigned char *y_src, int y_src_pitch, unsigned char *y_dest, int y_dest_pitch,
+ unsigned char *u_src, int u_src_pitch, unsigned char *u_dest, int u_dest_pitch,
+ unsigned char *v_src, int v_src_pitch, unsigned char *v_dest, int v_dest_pitch,
+ int width, int height);
#define SCALEFACTOR 65536
#define CENTERSAMPLE 128
@@ -701,8 +701,9 @@ static inline void _x_setenv(const char *name, const char *val, int _xx)
* Color Conversion Utility Functions
* The following data structures and functions facilitate the conversion
- * of RGB images to packed YUV (YUY2) images. All of the meaty details
- * are written in color.c.
+ * of RGB images to packed YUV (YUY2) images. There are also functions to
+ * convert from YUV9 -> YV12. All of the meaty details are written in
+ * color.c.
*/
typedef struct yuv_planes_s {